<?php
namespace Ecommerce\Controllers;

use Zeedhi\Framework\DTO\Request;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;

class TrocaFornecedor extends \Teknisa\Libs\Controller\CRUD
{
    protected $dataSourceName = 'fornecedoresRelacionados';
    protected $parameterBagColumns = array(
        "CDFORNECED",
        "CDFORNERELACAF",
        "NRORG"
    );

    protected $dataSourceManager;
    protected $fornecedor;

    public function __construct($crudService, $parameterBag, $dataSourceManager, $fornecedor) {
        $this->crudService = $crudService;
        $this->parameterBag = $parameterBag;
        $this->dataSourceManager = $dataSourceManager;
        $this->fornecedor = $fornecedor;
    }

    public function find(Request\Filter $request, Response $response) {
        try {
            $filterCriteria = $request->getFilterCriteria();
            $conditions = self::verificaCondicoes($filterCriteria->getConditions());
            $filterCriteria = self::montaNovoFilterCriteria($conditions);
            $newFilterCriteria = $this->crudService->getPopulatedFilterCriteria($filterCriteria, $this->parameterBagColumns);
            $dataSource = $this->dataSourceManager->findBy($newFilterCriteria);
            $dataSet = $this->fornecedor->formataMascara($dataSource->getRows(), $this->fornecedor->getObjectProviderType());
            $response->addDataSet(new DataSet('fornecedoresRelacionados', $dataSet));
        } catch (\Exception $e) {
            $response->setError(new Response\Error("Error in data save. ". $e->getMessage(), 500));
        }
    }

    public function verificaCondicoes($conditions){
        $cdforneced = $conditions[0]['value'];
        $cdfornerelacaf = $conditions[1]['value'];

        if(is_null($cdfornerelacaf)){
            $conditions[1]['value'] = $cdforneced;
        }

        return $conditions;
    }

    public function montaNovoFilterCriteria($conditions){
        $filterCriteria = new FilterCriteria($this->dataSourceName);

        $filterCriteria->addCondition('CDFORNECED', $conditions[0]['value']);
        $filterCriteria->addCondition('CDFORNERELACAF', $conditions[1]['value']);
        $filterCriteria->addCondition('NRORG', $conditions[2]['value']);

        return $filterCriteria;
    }

}